@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 #
-# $Id: mkconfig.pl,v 1.83 2010-07-19 07:25:53-07 bll Exp $
+# $Id: mkconfig.pl,v 1.86 2010-12-30 17:06:42-08 bll Exp $
 #
 # Copyright 2006-2010 Brad Lanam Walnut Creek, CA USA
 #
@@ -749,6 +749,142 @@ check_quotactl_pos
   printyesno_val $name, $r_config->{$name};
 }
 
+sub
+check_rquota_xdr
+{
+  my ($name, $r_clist, $r_config) = @_;
+
+  printlabel $name, "rquota xdr";
+  if (checkcache ($name, $r_config) == 0) {
+    return;
+  }
+
+  setlist $r_clist, $name;
+
+  if ($r_config->{'_hdr_rpcsvc_rquota'} eq '0') {
+    $r_config->{$name} = '0';
+    printyesno_val $name, $r_config->{$name};
+    return;
+  }
+
+  my $code = '';
+  my $hdr = $r_config->{'_hdr_rpcsvc_rquota'};
+  $code .= "#include <$hdr>\n";
+  my $rc = _check_cpp ($name, $code, {}, $r_clist, $r_config);
+  if ($rc == 0) {
+    $cmd = "sed '1,/struct *rquota *{/d' $name.out |
+        egrep '[	 ]*rq_bhardlimit[	 ]*;' >>$LOG 2>&1";
+    print LOGFH "##  rquota_xdr: $cmd\n";
+    $rc = system ($cmd);
+    if ($rc == 0) {
+      my $rval = `sed '1,/struct *rquota *{/d' $name.out |
+          egrep '[	 ]*rq_bhardlimit[	 ]*;'`;
+      chomp $rval;
+      $rval =~ s/[	 ][	 ]*rq_bhardlimit.*//;
+      $rval =~ s/^[	 ]*//;
+      $r_config->{$name} = "xdr_" . ${rval};
+      printyesno_val $name, $r_config->{$name};
+      return;
+    }
+  }
+
+  $r_config->{$name} = 0;
+  printyesno_val $name, $r_config->{$name};
+}
+
+sub
+check_gqa_uid_xdr
+{
+  my ($name, $r_clist, $r_config) = @_;
+
+  printlabel $name, "gqa_uid xdr";
+  if (checkcache ($name, $r_config) == 0) {
+    return;
+  }
+
+  setlist $r_clist, $name;
+
+  if ($r_config->{'_hdr_rpcsvc_rquota'} eq '0') {
+    $r_config->{$name} = '0';
+    printyesno_val $name, $r_config->{$name};
+    return;
+  }
+
+  my $code = '';
+  my $hdr = $r_config->{'_hdr_rpcsvc_rquota'};
+  $code .= "#include <$hdr>\n";
+  my $rc = _check_cpp ($name, $code, {}, $r_clist, $r_config);
+  if ($rc == 0) {
+    $cmd = "sed '1,/struct *getquota_args *{/d' $name.out |
+        egrep '[	 ]*gqa_uid[	 ]*;' >>$LOG 2>&1";
+    print LOGFH "##  gqa_uid_xdr: $cmd\n";
+    $rc = system ($cmd);
+    if ($rc == 0) {
+      my $rval = `sed '1,/struct *getquota_args *{/d' $name.out |
+          egrep '[	 ]*gqa_uid[	 ]*;'`;
+      chomp $rval;
+      $rval =~ s/[	 ][	 ]*gqa_uid.*//;
+      $rval =~ s/^[	 ]*//;
+      $r_config->{$name} = "xdr_" . ${rval};
+      printyesno_val $name, $r_config->{$name};
+      return;
+    }
+  }
+
+  $r_config->{$name} = 0;
+  printyesno_val $name, $r_config->{$name};
+}
+
+sub
+check_getfsstat_type
+{
+  my ($name, $r_clist, $r_config) = @_;
+
+  printlabel $name, "getfsstat type";
+  if (checkcache ($name, $r_config) == 0) {
+    return;
+  }
+
+  setlist $r_clist, $name;
+
+  if ($r_config->{'_lib_getfsstat'} eq '0') {
+    $r_config->{$name} = '0';
+    printyesno_val $name, $r_config->{$name};
+    return;
+  }
+
+  if ($r_config->{'_sys_mount'} eq '0') {
+    $r_config->{$name} = '0';
+    printyesno_val $name, $r_config->{$name};
+    return;
+  }
+
+  my $code = '';
+  my $hdr = $r_config->{'_sys_mount'};
+  $code .= "#include <$hdr>\n";
+  my $rc = _check_cpp ($name, $code, {}, $r_clist, $r_config);
+  if ($rc == 0) {
+    $cmd = "egrep -l 'getfsstat[	 ]*\\(' $name.out >>$LOG 2>&1";
+    $rc = system ($cmd);
+    print LOGFH "##  getfsstat_type: $cmd $rc\n";
+    if ($rc == 0) {
+      my $rval = `egrep 'getfsstat[	 ]*\\(' $name.out`;
+      print LOGFH "##  getfsstat_type: $rval\n";
+      chomp $rval;
+      $rval =~ s/^[^,]*,[	 ]*//;
+      $rval =~ s/,.*$//;
+      $rval =~ s/  *[_a-z0-9]*$//;  # strip any trailing var name
+      print LOGFH "##  getfsstat_type: $rval\n";
+      $r_config->{$name} = ${rval};
+      printyesno_val $name, $r_config->{$name};
+      return;
+    }
+  }
+
+  $r_config->{$name} = 0;
+  printyesno_val $name, $r_config->{$name};
+}
+
 sub
 check_include_conflict
 {
@@ -1474,6 +1610,18 @@ main_process
         {
             check_quotactl_pos ('_quotactl_pos', \%clist, \%config);
         }
+        elsif ($line =~ m#^\s*rquota_xdr$#o)
+        {
+            check_rquota_xdr ('_rquota_xdr', \%clist, \%config);
+        }
+        elsif ($line =~ m#^\s*gqa_uid_xdr$#o)
+        {
+            check_gqa_uid_xdr ('_gqa_uid_xdr', \%clist, \%config);
+        }
+        elsif ($line =~ m#^\s*getfsstat_type$#o)
+        {
+            check_getfsstat_type ('_getfsstat_type', \%clist, \%config);
+        }
         elsif ($line =~ m#^\s*include$#o)
         {
             print LOGFH "start include\n";
