@@ -1,6 +1,6 @@
 #!/bin/sh
 #
-# $Id: mkconfig.sh,v 1.82 2010-07-22 09:24:17-07 bll Exp $
+# $Id: mkconfig.sh,v 1.84 2010-12-28 20:45:52-08 bll Exp $
 #
 # Copyright 2009-2010 Brad Lanam Walnut Creek, CA USA
 #
@@ -21,6 +21,7 @@ if [ "$1" = "-d" ]; then
   shift
   shift
 fi
+unset CDPATH
 mypath=`echo $0 | sed -e 's,/[^/]*$,,'`
 _MKCONFIG_DIR=`(cd $mypath;pwd)`
 export _MKCONFIG_DIR
@@ -143,9 +144,9 @@ printyesno_val () {
   yntag=${3:-}
 
   if [ "$ynval" != "0" ]; then
-    printyesno_actual "$ynname" "$ynval" ${yntag}
+    printyesno_actual "$ynname" "$ynval" "${yntag}"
   else
-    printyesno_actual "$ynname" no ${yntag}
+    printyesno_actual "$ynname" no "${yntag}"
   fi
 }
 
