@@ -1,6 +1,6 @@
 #!/bin/sh
 #
-# $Id: env-cc.sh,v 1.26 2010-07-25 14:19:37-07 bll Exp $
+# $Id: env-cc.sh,v 1.27 2010-12-25 13:34:46-08 bll Exp $
 # $Source: /home/bll/DI/di/mkconfig/mkconfig.units/RCS/env-cc.sh,v $
 #
 # Copyright 2001-2010 Brad Lanam, Walnut Creek, California USA
@@ -21,11 +21,19 @@ require_unit env-systype
 
 env_dogetconf=F
 env_dohpflags=F
+_MKCONFIG_32BIT_FLAGS=F
 
 _dogetconf () {
   if [ "$env_dogetconf" = T ]; then
     return
   fi
+  if [ ${_MKCONFIG_32BIT_FLAGS} = T ]; then
+    lfccflags=""
+    lfldflags=""
+    lflibs=""
+    env_dogetconf=T
+    return
+  fi
 
   locatecmd xgetconf getconf
   if [ "${xgetconf}" != "" ]
@@ -68,6 +76,14 @@ _dohpflags () {
   env_dohpflags=T
 }
 
+check_32bitflags () {
+  _MKCONFIG_32BIT_FLAGS=T
+
+  printlabel _MKCONFIG_32BIT_FLAGS "32 bit flags"
+  printyesno_val _MKCONFIG_32BIT_FLAGS "${_MKCONFIG_32BIT_FLAGS}"
+  setdata ${_MKCONFIG_PREFIX} _MKCONFIG_32BIT_FLAGS "${_MKCONFIG_32BIT_FLAGS}"
+}
+
 check_cc () {
   CC=${CC:-cc}
 
@@ -94,6 +110,9 @@ check_cc () {
 
   printyesno_val CC "${CC}"
   setdata ${_MKCONFIG_PREFIX} CC "${CC}"
+  if [ ${_MKCONFIG_32BIT_FLAGS} = F ]; then
+    setdata ${_MKCONFIG_PREFIX} _MKCONFIG_32BIT_FLAGS "${_MKCONFIG_32BIT_FLAGS}"
+  fi
 }
 
 check_using_gcc () {
@@ -177,7 +196,7 @@ check_cflags () {
         ccincludes="-I/usr/local/include $ccincludes"
         ;;
       HP-UX)
-        if [ "${lfccflags}" = "" ]
+        if [ "${lfccflags}" = "" -a "${_MKCONFIG_32BIT_FLAGS}" = F ]
         then
             ccflags="-D_LARGEFILE64_SOURCE -D_FILE_OFFSET_BITS=64 $ccflags"
         fi
