@@ -1,6 +1,6 @@
 #!/bin/sh
 #
-# $Id: mkreqlib.sh,v 1.11 2010-07-22 09:57:05-07 bll Exp $
+# $Id: mkreqlib.sh,v 1.13 2010-12-28 20:46:04-08 bll Exp $
 #
 # Copyright 2009-2010 Brad Lanam Walnut Creek, CA USA
 #
@@ -11,6 +11,7 @@ if [ "$1" = "-d" ]; then
   shift
   shift
 fi
+unset CDPATH
 RUNTOPDIR=`pwd`
 mypath=`echo $0 | sed -e 's,/[^/]*$,,'`
 _MKCONFIG_DIR=`(cd $mypath;pwd)`
@@ -25,8 +26,9 @@ CACHEFILE="mkconfig.cache"
 getlibdata () {
     var=$1
     gdname=$2
+    lang=$3
 
-    cmd="${var}=\${di_c_lib_${gdname}}"
+    cmd="${var}=\${di_${lang}_lib_${gdname}}"
     eval $cmd
 }
 
@@ -70,6 +72,10 @@ exec 7<&0 < ${CONFH}
 while read cline; do
   case $cline in
     "#define _lib_"*1)
+      lang=c
+      ;;
+    "enum bool _lib_"*" = true;")
+      lang=d
       ;;
     *)
       continue
@@ -77,8 +83,8 @@ while read cline; do
   esac
 
   # bash2 can't handle # in subst
-  dosubst cline '#define ' '' ' 1' ''
-  getlibdata var $cline
+  dosubst cline '#define ' '' ' 1' '' ' = true;' '' 'enum bool' ''
+  getlibdata var $cline $lang
   if [ "$var" != "" ]; then
     echo $reqlibs | grep -- $var > /dev/null 2>&1
     rc=$?
