@@ -1,6 +1,6 @@
 #!/bin/sh
 #
-# $Id: runtests.sh,v 1.60 2010-07-23 15:56:13-07 bll Exp $
+# $Id: runtests.sh,v 1.63 2010-12-28 20:46:18-08 bll Exp $
 # $Source: /home/bll/DI/di/mkconfig/RCS/runtests.sh,v $
 #
 # Copyright 1994-2010 Brad Lanam, Walnut Creek, CA
@@ -17,6 +17,7 @@
 
 DOPERL=T
 TESTORDER=test_order
+SUBDIR=F
 
 # this is a workaround for ksh93 on solaris
 if [ "$1" = "-d" ]; then
@@ -24,16 +25,23 @@ if [ "$1" = "-d" ]; then
   shift
   shift
 fi
-_MKCONFIG_RUNTOPDIR=`pwd`
-export _MKCONFIG_RUNTOPDIR
-mypath=`echo $0 | sed -e 's,/[^/]*$,,'`
-_MKCONFIG_DIR=`(cd $mypath;pwd)`
-export _MKCONFIG_DIR
-. ${_MKCONFIG_DIR}/shellfuncs.sh
+unset CDPATH
 
-doshelltest $0 $@
-setechovars
-mkconfigversion
+if [ "$1" = "-s" ]; then
+  SUBDIR=T
+  shift
+  CC="$1"
+  DC="$2"
+  shelllist="$3"
+  _pthlist="$4"
+  TMPOUT="$5"
+  shift; shift; shift; shift; shift
+fi
+
+if [ $# -lt 1 ]; then
+  echo "Usage: $0 <test-dir> [<test-to-run> ...]"
+  exit 1
+fi
 
 unset GREP_OPTIONS
 unset DI_ARGS
@@ -46,24 +54,6 @@ unalias rm > /dev/null 2>&1
 LC_ALL=C
 export LC_ALL
 
-testdir=$1
-if [ ! -d $testdir ]; then
-  echo "## Unable to locate $testdir"
-  exit 1
-fi
-
-shift
-teststorun=$*
-
-CC=${CC:-cc}
-export CC
-
-cd $testdir
-if [ $? != 0 ]; then
-  echo "## Unable to cd to $testdir"
-  exit 1
-fi
-
 # this is used for regression testing.
 getlistofshells () {
 
@@ -169,38 +159,92 @@ runshelltest () {
   return $rc
 }
 
+#
+# main
+#
+
+_MKCONFIG_RUNTOPDIR=`pwd`
+export _MKCONFIG_RUNTOPDIR
+mypath=`echo $0 | sed -e 's,/[^/]*$,,'`
+_MKCONFIG_DIR=`(cd $mypath;pwd)`
+export _MKCONFIG_DIR
+. ${_MKCONFIG_DIR}/shellfuncs.sh
+
+doshelltest $0 $@
+if [ $SUBDIR = "F" ]; then
+  setechovars
+  mkconfigversion
+fi
+
+testdir=$1
+if [ ! -d $testdir ]; then
+  echo "## Unable to locate $testdir"
+  exit 1
+fi
+
+shift
+teststorun=$*
+
+cd $testdir
+if [ $? != 0 ]; then
+  echo "## Unable to cd to $testdir"
+  exit 1
+fi
+
 _MKCONFIG_RUNTESTDIR=`pwd`
 export _MKCONFIG_RUNTESTDIR
-_MKCONFIG_RUNTMPDIR=$_MKCONFIG_RUNTOPDIR/_mkconfig_runtests
-export _MKCONFIG_RUNTMPDIR
+
+if [ $SUBDIR = "F" ]; then
+  _MKCONFIG_RUNTMPDIR=$_MKCONFIG_RUNTOPDIR/_mkconfig_runtests
+  export _MKCONFIG_RUNTMPDIR
+
+  CC=${CC:-cc}
+  export CC
+  DC=${DC:-gdc}
+  export DC
+else
+  btestdir=`echo $testdir | sed 's,.*/,,'`
+  _MKCONFIG_RUNTMPDIR=$_MKCONFIG_RUNTOPDIR/_mkconfig_runtests/$btestdir
+  export _MKCONFIG_RUNTMPDIR
+fi
 
 TMPORDER=test_order.tmp
+> $TMPORDER
 if [ "$teststorun" = "" ]; then
   if [ ! -f "$TESTORDER" ]; then
-    ls -1d *.d *.sh 2>/dev/null | sed -e 's/\.sh$//' -e 's/^/1 ' > $TMPORDER
+    ls -1d *.d *.sh 2>/dev/null | sed -e 's/\.sh$//' -e 's/^/1 ' >> $TMPORDER
   else
-    sort -n $TESTORDER > $TMPORDER
+    sort -n $TESTORDER >> $TMPORDER
   fi
 else
   for t in $teststorun; do
     echo "1 $t"
-  done > $TMPORDER
+  done >> $TMPORDER
 fi
 
-test -d "$_MKCONFIG_RUNTMPDIR" && rm -rf "$_MKCONFIG_RUNTMPDIR"
-mkdir $_MKCONFIG_RUNTMPDIR
+if [ $SUBDIR = "F" ]; then
+  test -d $_MKCONFIG_RUNTMPDIR && rm -rf "$_MKCONFIG_RUNTMPDIR"
+fi
+test -d $_MKCONFIG_RUNTMPDIR || mkdir $_MKCONFIG_RUNTMPDIR
 
 MAINLOG=${_MKCONFIG_RUNTMPDIR}/main.log
-> $MAINLOG
+if [ $SUBDIR = "F" ]; then
+  > $MAINLOG
+fi
 exec 8>>$MAINLOG
-echo "## locating valid shells"
-echo ${EN} "   ${EC}"
-getlistofshells
-echo ""
+
+if [ $SUBDIR = "F" ]; then
+  echo "## locating valid shells"
+  echo ${EN} "   ${EC}"
+  getlistofshells
+  echo ""
+fi
+
 export shelllist
 grc=0
 count=0
 fcount=0
+fpass=0
 lastpass=""
 # save stdin in fd 7
 exec 7<&0 < ${TMPORDER}
@@ -212,16 +256,46 @@ while read tline; do
     lastpass=$pass
   fi
   if [ $grc -ne 0 -a "$lastpass" != "$pass" ]; then
-    echo "## stopping tests due to failures in pass $lastpass"
-    echo "## stopping tests due to failures in pass $lastpass" >&8
+    if [ $SUBDIR = "F" ]; then
+      echo "## stopping tests due to failures in $testdir/ pass $lastpass"
+    else
+      fpass=$lastpass
+    fi
+    echo "## stopping tests due to failures in $testdir/ pass $lastpass" >&8
     break
   fi
 
   if [ -d "$tbase" ]; then
-    $0 $tbase
+    ocwd=`pwd`
+    cd $_MKCONFIG_DIR
+    TMPOUT=${_MKCONFIG_TSTRUNTMPDIR}/${tbase}.out
+    ${_MKCONFIG_SHELL} ./runtests.sh -s "$CC" "$DC" "$shelllist" "$_pthlist" $TMPOUT $testdir/$tbase
+    retvals=`tail -1 $TMPOUT`
+    rm -f $TMPOUT > /dev/null 2>&1
+    set $retvals
+    retcount=$1
+    retfcount=$2
+    retfpass=$3
+    domath count "$count + $retcount"
+    domath fcount "$fcount + $retfcount"
+    rc=$retfcount
+    if [ $rc -ne 0 ]; then
+      grc=$rc
+      echo "## stopping tests due to failures in $testdir/$tbase/ pass $retfpass (pass $lastpass) "
+      echo "## stopping tests due to failures in $testdir/$tbase/ pass $retfpass (pass $lastpass)" >&8
+      break
+    fi
+    cd $ocwd
     continue
   fi
 
+  tprefix=`echo $tbase | sed 's/-.*//'`
+  if [ "${CC}" = "" -a "$tprefix" = "c" ]; then
+    continue
+  fi
+  if [ "${DC}" = "" -a "$tprefix" = "d" ]; then
+    continue
+  fi
   tf="${tbase}.sh"
   tconfig="${tbase}.config"
   tconfh="${tbase}.ctmp"
@@ -243,11 +317,12 @@ while read tline; do
   fi
 
   dt=`date`
-  arg=""
+  arg="mkconfig.sh"
   suffix=""
-  if [ -f ${tbase}.mksh -o -f ${tbase}.mkshpl ]; then
-    arg="mkconfig.sh"
+  if [ -f ${tbase}.mkshpl ]; then
     suffix="_sh"
+  else
+    suffix=""
   fi
 
   scount=""
@@ -294,11 +369,24 @@ while read tline; do
   fi
 
   if [ $src -ne 0 ]; then
-    echo " ... failed"
-    echo " failed" >&8
-    domath fcount "$fcount + 1"
     src=1
     grc=1
+    if [ $tbase = "c-compiler" -a $grc -ne 0 ]; then
+      CC=""
+      grc=0
+    fi
+    if [ $tbase = "d-compiler" -a $grc -ne 0 ]; then
+      DC=""
+      grc=0
+    fi
+    if [ $grc -eq 0 ]; then
+      echo " ... skipping $tprefix compiler tests"
+      echo " skipping $tprefix compiler tests" >&8
+    else
+      echo " ... failed"
+      echo " failed" >&8
+      domath fcount "$fcount + 1"
+    fi
   else
     echo " ... success"
     echo " success" >&8
@@ -365,11 +453,15 @@ fi
 
 exec 8>&-
 
-echo "$count tests $fcount failures"
-if [ $fcount -eq 0 ]; then
-  if [ "$MKC_KEEP_RUN_TMP" = "" ]; then
-    test -d "$_MKCONFIG_RUNTMPDIR" && rm -rf "$_MKCONFIG_RUNTMPDIR"
+if [ $SUBDIR = "F" ]; then
+  echo "$count tests $fcount failures"
+  if [ $fcount -eq 0 ]; then
+    if [ "$MKC_KEEP_RUN_TMP" = "" ]; then
+      test -d "$_MKCONFIG_RUNTMPDIR" && rm -rf "$_MKCONFIG_RUNTMPDIR"
+    fi
   fi
+else
+  echo "$count $fcount $fpass" > $TMPOUT
 fi
 
 exit $fcount
